summaryrefslogtreecommitdiffstats
path: root/chrome/browser/cocoa/browser_window_controller_unittest.mm
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/cocoa/browser_window_controller_unittest.mm')
-rw-r--r--chrome/browser/cocoa/browser_window_controller_unittest.mm8
1 files changed, 4 insertions, 4 deletions
diff --git a/chrome/browser/cocoa/browser_window_controller_unittest.mm b/chrome/browser/cocoa/browser_window_controller_unittest.mm
index 0d4975a..fbdef54 100644
--- a/chrome/browser/cocoa/browser_window_controller_unittest.mm
+++ b/chrome/browser/cocoa/browser_window_controller_unittest.mm
@@ -433,14 +433,14 @@ TEST_F(BrowserWindowControllerTest, BookmarkBarIsSameWidth) {
[bookmarkBarView frame].size.width);
}
-TEST_F(BrowserWindowControllerTest, TestTopLeftForBubble) {
- NSPoint p = [controller_ topLeftForBubble];
+TEST_F(BrowserWindowControllerTest, TestTopRightForBubble) {
+ NSPoint p = [controller_ topRightForBubble];
NSRect all = [[controller_ window] frame];
// As a sanity check make sure the point is vaguely in the top left
// of the window.
EXPECT_GT(p.y, all.origin.y + (all.size.height/2));
- EXPECT_LT(p.x, all.origin.x + (all.size.width/2));
+ EXPECT_GT(p.x, all.origin.x + (all.size.width/2));
}
// By the "zoom frame", we mean what Apple calls the "standard frame".
@@ -433,14 +433,14 @@ TEST_F(BrowserWindowControllerTest, BookmarkBarIsSameWidth) {
NSRect all = [[controller_ window] frame];
- // As a sanity check make sure the point is vaguely in the top left
+ // As a sanity check make sure the point is vaguely in the top right
// of the window.
EXPECT_GT(p.y, all.origin.y + (all.size.height/2));